@@ -192,10 +192,11 @@ class FaasJobManager(metaclass=Singleton):
                         parent_ref=req.task_parent_ref,
                         name=task_name,
                     )
+                    task_info_dict = asdict(task_info)
                     job_data["tasks_info"][str(self.ref_pow)] = Entity(
-                        exclude_from_indexes=tuple(task_info.keys())
+                        exclude_from_indexes=tuple(task_info_dict.keys())
                     )
-                    job_data["tasks_info"][str(self.ref_pow)].update(asdict(task_info))
+                    job_data["tasks_info"][str(self.ref_pow)].update(task_info_dict)
                 job_data["tasks_info"][str(self.ref_pow)]["state"] = _task_state.name
 
                 _multi_data.append(job_data)
